@@ -54,7 +54,9 @@ class Account:
                 "page": page,
             },
         )
-        return GetWithdrawalsResponse._from_data(resp.json())
+        return GetWithdrawalsResponse._from_data(
+            dict(resp.json(), _client=self._client)
+        )
 
     def withdraw(
         self,
@@ -92,7 +94,9 @@ class Account:
                 "page": page,
             },
         )
-        return GetBankStatementsResponse._from_data(resp.json())
+        return GetBankStatementsResponse._from_data(
+            dict(resp.json(), _client=self._client)
+        )
 
     def get_documents(
         self,
@@ -108,7 +112,7 @@ class Account:
                 "page": page,
             },
         )
-        return GetDocumentsResponse._from_data(resp.json())
+        return GetDocumentsResponse._from_data(dict(resp.json(), _client=self._client))
 
     def get_document(
         self, document_id: str, no_redirect: Optional[bool] = None
