@@ -1,5 +1,6 @@
+import re
 from datetime import date
-from typing import Optional, Union
+from typing import List, Optional, Union
 
 from lemon.base import Client
 from lemon.trading.model import (
@@ -26,7 +27,7 @@ class Orders:
         to: Optional[date] = None,
         isin: Optional[str] = None,
         side: Optional[OrderSide] = None,
-        status: Optional[OrderStatus] = None,
+        status: Optional[Union[OrderStatus, List[OrderStatus]]] = None,
         type: Optional[OrderType] = None,
         key_creation_id: Optional[str] = None,
         limit: Optional[int] = None,
@@ -46,14 +47,14 @@ class Orders:
                 "page": page,
             },
         )
-        return GetOrdersResponse._from_data(resp.json())
+        return GetOrdersResponse._from_data(dict(resp.json(), _client=self._client))
 
     def create(
         self,
         isin: str,
         side: OrderSide,
         quantity: int,
-        expires_at: Union[date, Days, None] = None,
+        expires_at: Union[date, Days, str, None] = None,
         stop_price: Optional[int] = None,
         limit_price: Optional[int] = None,
         venue: Optional[Venue] = None,
@@ -64,6 +65,12 @@ class Orders:
             expires_at_str = expires_at.isoformat()
         elif isinstance(expires_at, int):
             expires_at_str = f"P{expires_at}D"
+        elif isinstance(expires_at, str):
+            expires_at_str = expires_at.strip().upper()
+            if re.match(r"^P?\d+D$", expires_at_str) is None:
+                raise ValueError(
+                    "Invalid 'expires_at' format ('pXd' or 'Xd' are allowed where X is a non-negative integer)"
+                )
         else:
             expires_at_str = None
 
