@@ -1,10 +1,12 @@
 import json
-from dataclasses import asdict
-from datetime import date, datetime, time
-from typing import Any, Callable, Dict, Tuple, Type, TypeVar, Union
+from dataclasses import asdict, dataclass
+from datetime import date, datetime, time, timezone
+from typing import Any, Callable, Dict, Iterator, Optional, Tuple, Type, TypeVar, Union
 
 from typing_extensions import Literal
 
+from lemon.errors import APIError
+
 Sorting = Literal["asc", "desc"]
 Environment = Literal["paper", "money"]
 Days = int
@@ -21,8 +23,18 @@ def filter_out_optionals(data: Dict[str, Any]) -> Dict[str, Any]:
     return {k: v for k, v in data.items() if v is not None}
 
 
+def convert_datetime(value: Union[str, int]) -> datetime:
+    try:
+        return datetime.fromisoformat(value)
+    except:
+        try:
+            return datetime.fromtimestamp(value / 1000, tz=timezone.utc)
+        except Exception as exc:
+            raise APIError(exc) from exc
+
+
 BASIC_PARSERS = {
-    datetime: datetime.fromisoformat,
+    datetime: convert_datetime,
     date: lambda value: datetime.fromisoformat(value).date(),
 }
 
@@ -65,17 +77,30 @@ class BaseModelMeta(type):
     def __new__(
         cls, name: str, bases: Tuple[Any], dct: Dict[str, Any]
     ) -> "BaseModelMeta":
-        if "__annotations__" not in dct:
-            return super().__new__(cls, name, bases, dct)
+        slots, parsers = set(), {}
 
-        annotations = dct["__annotations__"]
-        dct["_parsers"] = {
-            key: _make_parser(type_) for key, type_ in annotations.items()
-        }
-        dct["__slots__"] = tuple(annotations.keys())
+        for base in [*bases, dct]:
+            annotations = (
+                base.get("__annotations__", {})
+                if isinstance(base, dict)
+                else getattr(base, "__annotations__", {})
+            )
+            slots.update(annotations)
+
+            if isinstance(base, (BaseModelMeta, dict)):
+                parsers.update(cls.make_parsers(annotations))
+
+        dct["_parsers"] = parsers
+        dct["__slots__"] = tuple(sorted(slots))
 
         return super().__new__(cls, name, bases, dct)
 
+    @staticmethod
+    def make_parsers(annotations: Dict[str, Any]) -> Dict[str, Any]:
+        return {
+            k: _make_parser(v) for k, v in annotations.items() if not k.startswith("_")
+        }
+
 
 TBaseModel = TypeVar("TBaseModel", bound="BaseModel")
 
@@ -91,10 +116,34 @@ class BaseModel(metaclass=BaseModelMeta):
 
     @classmethod
     def _from_data(cls: Type[TBaseModel], data: Dict[str, Any]) -> TBaseModel:
-        kwargs = {}
+        kwargs, attr_names = {}, cls.__slots__
 
-        for key, parser in cls._parsers.items():  # type: ignore # pylint: disable=E1101
-            val = data.get(key)
-            kwargs[key] = parser(val) if val is not None else None
+        for attr_name in attr_names:
+            val = data.get(attr_name)
+            try:
+                parser = cls._parsers[attr_name]
+            except KeyError:
+                # set private variable
+                kwargs[attr_name] = val
+            else:
+                kwargs[attr_name] = parser(val) if val is not None else None
 
         return cls(**kwargs)
+
+
+@dataclass
+class BaseIterableModel(BaseModel):
+    next: Optional[str]
+    _client: Optional["Client"]
+
+    def auto_iter(self) -> Iterator:
+        data = self
+        while True:
+            for el in data.results:
+                yield el
+
+            if not data.next:
+                break
+
+            response = self._client.get(data.next).json()
+            data = self._from_data(response)
